Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(377)

Unified Diff: src/ia32/macro-assembler-ia32.h

Issue 7113012: Call a stub for the write barrier on ARM. This is a step (Closed) Base URL: http://v8.googlecode.com/svn/branches/experimental/gc/
Patch Set: '' Created 9 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/ia32/code-stubs-ia32.cc ('k') | src/ia32/macro-assembler-ia32.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/ia32/macro-assembler-ia32.h
===================================================================
--- src/ia32/macro-assembler-ia32.h (revision 8184)
+++ src/ia32/macro-assembler-ia32.h (working copy)
@@ -99,18 +99,18 @@
Label* condition_met,
Label::Distance condition_met_distance = Label::kFar);
// Check if an object has a given incremental marking colour. Also uses ecx!
// The colour bits are found by splitting the address at the bit offset
// indicated by the mask: bits that are zero in the mask are used for the
// address of the bitmap, and bits that are one in the mask are used for the
// index of the bit.
- void HasColour(Register object,
- Register scratch0,
- Register scratch1,
- Label* has_colour,
- Label::Distance has_colour_distance,
- int first_bit,
- int second_bit);
+ void HasColor(Register object,
+ Register scratch0,
+ Register scratch1,
+ Label* has_color,
+ Label::Distance has_color_distance,
+ int first_bit,
+ int second_bit);
void IsBlack(Register object,
Register scratch0,
@@ -118,7 +118,7 @@
Label* is_black,
Label::Distance is_black_distance = Label::kFar);
// Checks the colour of an object. If the object is already grey or black
// then we just fall through, since it is already live. If it is white and
// we can determine that it doesn't need to be scanned, then we just mark it
// black and fall through. For the rest we jump to the label so the
@@ -788,9 +788,9 @@
// bitmap register points at the word with the mark bits and the mask
// the position of the first bit. Uses ecx as scratch and leaves addr_reg
// unchanged.
- inline void MarkBits(Register addr_reg,
- Register bitmap_reg,
- Register mask_reg);
+ inline void GetMarkBits(Register addr_reg,
+ Register bitmap_reg,
+ Register mask_reg);
// Compute memory operands for safepoint stack slots.
Operand SafepointRegisterSlot(Register reg);
« no previous file with comments | « src/ia32/code-stubs-ia32.cc ('k') | src/ia32/macro-assembler-ia32.cc » ('j') | no next file with comments »
@@ -99,18 +99,18 @@
Label* condition_met,
Label::Distance condition_met_distance = Label::kFar);
- // Check if an object has a given incremental marking colour. Also uses ecx!
- // The colour bits are found by splitting the address at the bit offset
+ // Check if an object has a given incremental marking color. Also uses ecx!
+ // The color bits are found by splitting the address at the bit offset
// indicated by the mask: bits that are zero in the mask are used for the
// address of the bitmap, and bits that are one in the mask are used for the
@@ -118,7 +118,7 @@
Label* is_black,
Label::Distance is_black_distance = Label::kFar);
- // Checks the colour of an object. If the object is already grey or black
+ // Checks the color of an object. If the object is already grey or black
// then we just fall through, since it is already live. If it is white and
// we can determine that it doesn't need to be scanned, then we just mark it

Powered by Google App Engine
This is Rietveld 408576698